@@ -63,19 +63,21 @@
 #'
 #' # Print three-digit mean with subscript in LaTeX
 #' format_summary(mtcars$mpg, digits = 3, subscript = "control", display = "none", type = "latex")
-format_summary <- function(x = NULL,
-                           tendency = "mean",
-                           error = "ci",
-                           values = NULL,
-                           digits = 1,
-                           tendlabel = "abbr",
-                           italics = TRUE,
-                           subscript = NULL,
-                           units = NULL,
-                           display = "limits",
-                           cilevel = 0.95,
-                           errorlabel = TRUE,
-                           type = "md") {
+format_summary <- function(
+  x = NULL,
+  tendency = "mean",
+  error = "ci",
+  values = NULL,
+  digits = 1,
+  tendlabel = "abbr",
+  italics = TRUE,
+  subscript = NULL,
+  units = NULL,
+  display = "limits",
+  cilevel = 0.95,
+  errorlabel = TRUE,
+  type = "md"
+) {
   # Check arguments
   if (!is.null(x)) {
     check_numeric(x)
@@ -86,7 +88,10 @@ format_summary <- function(x = NULL,
       identical(tendency, "median") ~ median(x, na.rm = TRUE)
     )
     xn <- sum(!is.na(x))
-    stopifnot("Less than two values in vector, so no confidence interval can be computed." = xn > 1)
+    stopifnot(
+      "Less than two values in vector, so no confidence interval can be computed." = xn >
+        1
+    )
     xlimit <- 1 - (1 - cilevel) / 2
     xsd <- stats::sd(x, na.rm = TRUE)
     xse <- xsd / sqrt(xn)
@@ -107,16 +112,25 @@ format_summary <- function(x = NULL,
     xinterval <- xtendency - xlower
   } else if (!is.null(values)) {
     check_numeric(values)
-    stopifnot("Argument `values` must be a vector with two or three elements." =
-                length(values) %in% c(2, 3))
+    stopifnot(
+      "Argument `values` must be a vector with two or three elements." = length(
+        values
+      ) %in%
+        c(2, 3)
+    )
     if (length(values) == 2) {
       xtendency <- values[1]
       xinterval <- values[2]
       xlower <- xtendency - xinterval
       xupper <- xtendency + xinterval
     } else {
-      stopifnot("Argument `values` must include the mean followed by the lower CI limit then the upper CI limit." =
-                  values[1] >= values[2] & values[1] <= values[3])
+      stopifnot(
+        "Argument `values` must include the mean followed by the lower CI limit then the upper CI limit." = values[
+          1
+        ] >=
+          values[2] &
+          values[1] <= values[3]
+      )
       xtendency <- values[1]
       xlower <- values[2]
       xupper <- values[3]
@@ -138,17 +152,29 @@ format_summary <- function(x = NULL,
     identical(tendlabel, "none") ~
       "",
     identical(tendency, "mean") & identical(tendlabel, "abbr") ~
-      paste0(format_chr("M", italics = italics, type = type),
-             format_sub(subscript, type = type), " = "),
+      paste0(
+        format_chr("M", italics = italics, type = type),
+        format_sub(subscript, type = type),
+        " = "
+      ),
     identical(tendency, "mean") & identical(tendlabel, "word") ~
-      paste0(format_chr("Mean", italics = italics, type = type),
-             format_sub(subscript, type = type), " = "),
+      paste0(
+        format_chr("Mean", italics = italics, type = type),
+        format_sub(subscript, type = type),
+        " = "
+      ),
     identical(tendency, "median") & identical(tendlabel, "abbr") ~
-      paste0(format_chr("Mdn", italics = italics, type = type),
-             format_sub(subscript, type = type), " = "),
+      paste0(
+        format_chr("Mdn", italics = italics, type = type),
+        format_sub(subscript, type = type),
+        " = "
+      ),
     identical(tendency, "median") & identical(tendlabel, "word") ~
-      paste0(format_chr("Median", italics = italics, type = type),
-             format_sub(subscript, type = type), " = ")
+      paste0(
+        format_chr("Median", italics = italics, type = type),
+        format_sub(subscript, type = type),
+        " = "
+      )
   )
   full_mean <- paste0(mean_lab, format_num(xtendency, digits = digits), unit)
 
@@ -166,13 +192,26 @@ format_summary <- function(x = NULL,
   )
   full_error <- dplyr::case_when(
     identical(display, "limits") ~
-      paste0(", ", error_lab, " [", format_num(xlower, digits = digits), ", ",
-             format_num(xupper, digits = digits), "]"),
+      paste0(
+        ", ",
+        error_lab,
+        " [",
+        format_num(xlower, digits = digits),
+        ", ",
+        format_num(xupper, digits = digits),
+        "]"
+      ),
     identical(display, "pm") ~
       paste0(" \u00b1 ", format_num(xinterval, digits = digits)),
     identical(display, "par") ~
-      paste0(" ", "(", error_lab, " = ",
-             format_num(xinterval, digits = digits), ")"),
+      paste0(
+        " ",
+        "(",
+        error_lab,
+        " = ",
+        format_num(xinterval, digits = digits),
+        ")"
+      ),
     .default = ""
   )
   paste0(full_mean, full_error)
@@ -180,115 +219,186 @@ format_summary <- function(x = NULL,
 
 #' @rdname format_summary
 #' @export
-format_mean <- function(x = NULL,
-                        tendency = "mean",
-                        values = NULL,
-                        digits = 1,
-                        tendlabel = "abbr",
-                        italics = TRUE,
-                        subscript = NULL,
-                        units = NULL,
-                        display = "none",
-                        type = "md") {
-  format_summary(x = x, tendency = tendency, values = values, digits = digits,
-                 tendlabel = tendlabel, italics = italics, subscript = subscript,
-                 units = units, display = display, type = type)
+format_mean <- function(
+  x = NULL,
+  tendency = "mean",
+  values = NULL,
+  digits = 1,
+  tendlabel = "abbr",
+  italics = TRUE,
+  subscript = NULL,
+  units = NULL,
+  display = "none",
+  type = "md"
+) {
+  format_summary(
+    x = x,
+    tendency = tendency,
+    values = values,
+    digits = digits,
+    tendlabel = tendlabel,
+    italics = italics,
+    subscript = subscript,
+    units = units,
+    display = display,
+    type = type
+  )
 }
 
 #' @rdname format_summary
 #' @export
-format_meanci <- function(x = NULL,
-                          tendency = "mean",
-                          error = "ci",
-                          values = NULL,
-                          digits = 1,
-                          tendlabel = "abbr",
-                          italics = TRUE,
-                          subscript = NULL,
-                          units = NULL,
-                          display = "limits",
-                          cilevel = 0.95,
-                          errorlabel = TRUE,
-                          type = "md") {
-  format_summary(x = x, tendency = tendency, error = error, values = values,
-                 digits = digits, tendlabel = tendlabel, italics = italics,
-                 subscript = subscript, units = units, display = display,
-                 cilevel = cilevel, errorlabel = errorlabel, type = type)
+format_meanci <- function(
+  x = NULL,
+  tendency = "mean",
+  error = "ci",
+  values = NULL,
+  digits = 1,
+  tendlabel = "abbr",
+  italics = TRUE,
+  subscript = NULL,
+  units = NULL,
+  display = "limits",
+  cilevel = 0.95,
+  errorlabel = TRUE,
+  type = "md"
+) {
+  format_summary(
+    x = x,
+    tendency = tendency,
+    error = error,
+    values = values,
+    digits = digits,
+    tendlabel = tendlabel,
+    italics = italics,
+    subscript = subscript,
+    units = units,
+    display = display,
+    cilevel = cilevel,
+    errorlabel = errorlabel,
+    type = type
+  )
 }
 
 #' @rdname format_summary
 #' @export
-format_meanse <- function(x = NULL,
-                          tendency = "mean",
-                          error = "se",
-                          values = NULL,
-                          digits = 1,
-                          tendlabel = "abbr",
-                          italics = TRUE,
-                          subscript = NULL,
-                          units = NULL,
-                          display = "par",
-                          errorlabel = TRUE,
-                          type = "md") {
-  format_summary(x = x, tendency = tendency, error = error, values = values,
-                 digits = digits, tendlabel = tendlabel, italics = italics,
-                 subscript = subscript, units = units, display = display,
-                 errorlabel = errorlabel, type = type)
+format_meanse <- function(
+  x = NULL,
+  tendency = "mean",
+  error = "se",
+  values = NULL,
+  digits = 1,
+  tendlabel = "abbr",
+  italics = TRUE,
+  subscript = NULL,
+  units = NULL,
+  display = "par",
+  errorlabel = TRUE,
+  type = "md"
+) {
+  format_summary(
+    x = x,
+    tendency = tendency,
+    error = error,
+    values = values,
+    digits = digits,
+    tendlabel = tendlabel,
+    italics = italics,
+    subscript = subscript,
+    units = units,
+    display = display,
+    errorlabel = errorlabel,
+    type = type
+  )
 }
 
 #' @rdname format_summary
 #' @export
-format_meansd <- function(x = NULL,
-                          tendency = "mean",
-                          error = "sd",
-                          values = NULL,
-                          digits = 1,
-                          tendlabel = "abbr",
-                          italics = TRUE,
-                          subscript = NULL,
-                          units = NULL,
-                          display = "par",
-                          errorlabel = TRUE,
-                          type = "md") {
-  format_summary(x = x, tendency = tendency, error = error, values = values,
-                 digits = digits, tendlabel = tendlabel, italics = italics,
-                 subscript = subscript, units = units, display = display,
-                 errorlabel = errorlabel, type = type)
+format_meansd <- function(
+  x = NULL,
+  tendency = "mean",
+  error = "sd",
+  values = NULL,
+  digits = 1,
+  tendlabel = "abbr",
+  italics = TRUE,
+  subscript = NULL,
+  units = NULL,
+  display = "par",
+  errorlabel = TRUE,
+  type = "md"
+) {
+  format_summary(
+    x = x,
+    tendency = tendency,
+    error = error,
+    values = values,
+    digits = digits,
+    tendlabel = tendlabel,
+    italics = italics,
+    subscript = subscript,
+    units = units,
+    display = display,
+    errorlabel = errorlabel,
+    type = type
+  )
 }
 
 #' @rdname format_summary
 #' @export
-format_median <- function(x = NULL,
-                          tendency = "median",
-                          values = NULL,
-                          digits = 1,
-                          tendlabel = "abbr",
-                          italics = TRUE,
-                          subscript = NULL,
-                          units = NULL,
-                          display = "none",
-                          type = "md") {
-  format_summary(x = x, tendency = tendency, values = values, digits = digits,
-                 tendlabel = tendlabel, italics = italics, subscript = subscript,
-                 units = units, display = display, type = type)
+format_median <- function(
+  x = NULL,
+  tendency = "median",
+  values = NULL,
+  digits = 1,
+  tendlabel = "abbr",
+  italics = TRUE,
+  subscript = NULL,
+  units = NULL,
+  display = "none",
+  type = "md"
+) {
+  format_summary(
+    x = x,
+    tendency = tendency,
+    values = values,
+    digits = digits,
+    tendlabel = tendlabel,
+    italics = italics,
+    subscript = subscript,
+    units = units,
+    display = display,
+    type = type
+  )
 }
 
 #' @rdname format_summary
 #' @export
-format_medianiqr <- function(x = NULL,
-                             tendency = "median",
-                             error = "iqr",
-                             values = NULL,
-                             digits = 1,
-                             tendlabel = "abbr",
-                             italics = TRUE,
-                             subscript = NULL,
-                             units = NULL,
-                             display = "par",
-                             errorlabel = TRUE,
-                             type = "md") {
-  format_summary(x = x, tendency = tendency, error = error, values = values,
-                 digits = digits, tendlabel = tendlabel, italics = italics,
-                 subscript = subscript, units = units, display = display,
-                 errorlabel = errorlabel, type = type)
+format_medianiqr <- function(
+  x = NULL,
+  tendency = "median",
+  error = "iqr",
+  values = NULL,
+  digits = 1,
+  tendlabel = "abbr",
+  italics = TRUE,
+  subscript = NULL,
+  units = NULL,
+  display = "par",
+  errorlabel = TRUE,
+  type = "md"
+) {
+  format_summary(
+    x = x,
+    tendency = tendency,
+    error = error,
+    values = values,
+    digits = digits,
+    tendlabel = tendlabel,
+    italics = italics,
+    subscript = subscript,
+    units = units,
+    display = display,
+    errorlabel = errorlabel,
+    type = type
+  )
 }
